@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 from construct import *
 from binascii import hexlify,unhexlify
-from codec_Watteco.ZCL_FRAME import *
-from codec_Watteco.WTC_CodecTools import *
-from codec_Watteco.TICs import *
+from ZCL_FRAME import *
+from WTC_CodecTools import *
+from TICs import *
  
 
 
@@ -126,11 +126,11 @@ _XYZAccParamsStruct_ = Struct(
 	"FilterSmoothCoef" / Int8ub,
 	"FilterGainCoef" / Int8ub,
 	Embedded("WorkingModes" / BitStruct(
-		"SignalEachAcq" / Enum(Bit, Yes = 1 , No = 0),
-		"Reserved" / BitsInteger(4),
-		"RstAftStdRpt_X" / Enum(Bit, Yes = 1 , No = 0),
-		"RstAftStdRpt_Y" / Enum(Bit, Yes = 1 , No = 0),
-		"RstAftStdRpt_Z" / Enum(Bit, Yes = 1 , No = 0)
+		"WM_SignalEachAcq" / Enum(Bit, Yes = 1 , No = 0),
+		"WM_Reserved" / BitsInteger(4),
+		"WM_RstAftStdRpt_X" / Enum(Bit, Yes = 1 , No = 0),
+		"WM_RstAftStdRpt_Y" / Enum(Bit, Yes = 1 , No = 0),
+		"WM_RstAftStdRpt_Z" / Enum(Bit, Yes = 1 , No = 0)
 	))
 )
 
@@ -594,12 +594,12 @@ _TICData_ = Switch( FindClusterID ,{
 TICCFGReportData = Struct(
 	"TICReportSelector" / TICFieldsSelector,
 	"TICDataSelector"   / TICFieldsSelector,
-	"TICCriteriaFields" / _TICData_
+	Embedded ("TICCriteriaFields" / _TICData_)
 )
  
 TICData = Struct(
 	"TICDataSelector" / TICFieldsSelector,
-	"TICDataFields"   / _TICData_
+	Embedded ("TICDataFields"   / _TICData_)
 )
 
 
